@@ -234,6 +234,60 @@ def api_mock():
                     },
                 },
             },
+            "60002AE2F1BE": {
+                "nativeId": "abcd12350",
+                "deviceId": "0004",
+                "displayName": "MyVirtualDoorSensor",
+                "unresponsive": False,
+                "unresponsiveCounter": 0,
+                "defect": False,
+                "channels": {
+                    "ch0000": {
+                        "displayName": "MyVirtualDoorSensor",
+                        "floor": "01",
+                        "room": "01",
+                        "functionID": "f",
+                        "inputs": {},
+                        "outputs": {"odp000c": {"pairingID": 53, "value": ""}},
+                        "parameters": {"par0010": "1"},
+                        "selectedIcon": "51",
+                    }
+                },
+                "parameters": {},
+            },
+            "60005D808C54": {
+                "floor": "01",
+                "room": "01",
+                "nativeId": "virtual-switch-sleep",
+                "interface": "vdev:installer@busch-jaeger.de",
+                "deviceId": "0001",
+                "displayName": "Sleepmode",
+                "unresponsive": False,
+                "unresponsiveCounter": 0,
+                "defect": False,
+                "channels": {
+                    "ch0000": {
+                        "displayName": "Sleepmode",
+                        "floor": "01",
+                        "room": "01",
+                        "functionID": "7",
+                        "inputs": {
+                            "idp0000": {"pairingID": 1, "value": "1"},
+                            "idp0001": {"pairingID": 2, "value": ""},
+                            "idp0002": {"pairingID": 3, "value": ""},
+                            "idp0003": {"pairingID": 4, "value": ""},
+                            "idp0004": {"pairingID": 6, "value": ""},
+                        },
+                        "outputs": {
+                            "odp0000": {"pairingID": 256, "value": "0"},
+                            "odp0001": {"pairingID": 257, "value": "0"},
+                        },
+                        "parameters": {"par0015": "60", "par0014": "1"},
+                        "selectedIcon": "0B",
+                    }
+                },
+                "parameters": {},
+            },
         },
     }
     return api
@@ -243,7 +297,9 @@ def api_mock():
 def freeathome(api_mock):
     """Create the FreeAtHome fixture."""
     return FreeAtHome(
-        api=api_mock, interfaces=[Interface.WIRED_BUS], include_orphan_channels=False
+        api=api_mock,
+        interfaces=[Interface.WIRED_BUS],
+        include_orphan_channels=False,
     )
 
 
@@ -251,7 +307,20 @@ def freeathome(api_mock):
 def freeathome_orphans(api_mock):
     """Create the FreeAtHome fixture."""
     return FreeAtHome(
-        api=api_mock, interfaces=[Interface.WIRED_BUS], include_orphan_channels=True
+        api=api_mock,
+        interfaces=[Interface.WIRED_BUS],
+        include_orphan_channels=True,
+    )
+
+
+# This can be removed, when ABB fixes the bug
+@pytest.fixture
+def freeathome_virtuals(api_mock):
+    """Create the FreeAtHome fixture."""
+    return FreeAtHome(
+        api=api_mock,
+        interfaces=[Interface.VIRTUAL_DEVICE],
+        include_orphan_channels=False,
     )
 
 
@@ -347,6 +416,7 @@ async def test_load_devices(freeathome):
     assert devices[device_key].channel_name == "Study Area Light"
     assert devices[device_key].floor_name == "Ground Floor"
     assert devices[device_key].room_name == "Living Room"
+    assert devices[device_key].is_virtual is False
 
     # Unload a single device and test it's been removed
     freeathome.unload_device_by_device_serial(device_serial="ABB7F62F6C0B")
@@ -375,6 +445,28 @@ async def test_load_devices_with_orphans(freeathome_orphans):
     assert devices[device_key].room_name is None
 
 
+@pytest.mark.asyncio
+async def test_load_devices_with_virtuals(freeathome_virtuals):
+    """Test the load_devices function."""
+    await freeathome_virtuals.load_devices()
+
+    # Get the dict of devices
+    devices = freeathome_virtuals.get_devices()
+
+    # Verify that the devices are loaded correctly
+    assert len(devices) == 2
+
+    # Check a single virtual device
+    device_key = "60005D808C54/ch0000"
+    assert device_key in devices
+    assert isinstance(devices[device_key], SwitchActuator)
+    assert devices[device_key].device_name == "Sleepmode"
+    assert devices[device_key].channel_name == "Sleepmode"
+    assert devices[device_key].floor_name == "Ground Floor"
+    assert devices[device_key].room_name == "Living Room"
+    assert devices[device_key].is_virtual is True
+
+
 @pytest.mark.asyncio
 async def test_ws_close(freeathome, api_mock):
     "Test the ws_close function."
